
# mypackage.utils


Equation from Markdown:

```math
f(x) = \int_{-\infty}^\infty
    \hat f(\xi)\,e^{2 \pi i \xi x}
    \,d\xi
```

::: mypackage.utils.echo

::: mypackage.utils.Example
    selection:
      members:
        - __init__
        - adapt
